@@ -70,6 +70,15 @@ def submit_ssi(dbfile, ssi):
 			conn.execute(f"replace into ssi(s,i) values(?,?)", (f"{k}:{s}",i))
 	conn.commit()
 
+def submit_wav(dbfile, ssi): # added 2022.5.22
+	conn = sqlite3.connect(dbfile, check_same_thread=False)  
+	conn.execute(f'DROP TABLE IF EXISTS wav')
+	conn.execute(f'CREATE TABLE IF NOT EXISTS wav (word varchar(64), attr varchar(64), val int, PRIMARY KEY(word, attr) ) without rowid') # sim (key, hkey, hval)  
+	for k,v in ssi.items(): #redis.dm.zadd(f"{corpus}:{k}", dict(v))
+		for s,i in v.items(): 
+			conn.execute(f"replace into wav(word, attr,val) values(?,?,?)", (k, s,i))
+	conn.commit()
+
 def readline(infile, sepa=None):
 	with open(infile, 'r') as fp:
 		while True:
@@ -134,6 +143,40 @@ class util(object):
 		submit_ssi(outfile, ssi)
 		print (f"[index] finished, {dbfile} -> {outfile}")
 
+	def towav(self,dbfile, outfile=None, fts=True, topk=None):  
+		''' clec.spacybs -> clec.sqlwav, 2022.5.22 '''
+		if not outfile : outfile  = dbfile.split('.')[0] + ".sqlwav" 
+		print (f"[index] started, {dbfile} -> {outfile}", flush=True)
+		if fts: conn = init_db(outfile)
+		ssi = defaultdict(Counter) 
+		for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
+			try:
+				doc = spacy.frombs(bs)
+				terms.zset_ssi(doc, ssi)
+				if fts: doc_fts(conn, rowid, snt, doc) 
+				if topk is not None and rowid > topk : break # add 2022.3.29, wiki.spacybs is too big , 50G memory is not enough
+			except Exception as e:
+				print ("ex:", e, rowid, snt)
+		if fts: conn.commit()
+		print (f"start to dump wav, {dbfile} -> {outfile}")
+		submit_wav(outfile, ssi)
+		print (f"[index] finished, {dbfile} -> {outfile}")
+
+	def tojson(self,dbfile, outfile=None):  
+		''' clec.spacybs -> clec.JSONEachRow, 2022.5.23 '''
+		if not outfile : outfile  = dbfile.split('.')[0] + ".JSONEachRow" 
+		print (f"[index] started, {dbfile} -> {outfile}", flush=True)
+		with open(outfile, 'w') as fw: 
+			for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
+				try:
+					doc = spacy.frombs(bs)
+					for t in doc: #arr = [ {'sid': rowid, 'i':t.i, "head":t.head.i, 'lex':t.text, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gpos":t.head.pos_, "glem":t.head.lemma_} for t in doc]
+						arr = {'sid': rowid, 'i':t.i, "head":t.head.i, 'lex':t.text, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gpos":t.head.pos_, "glem":t.head.lemma_}
+						fw.write(json.dumps(arr)+"\n") 
+				except Exception as e:
+					print ("ex:", e, rowid, snt)
+		print (f"[index] finished, {dbfile} -> {outfile}")
+
 	def indexdoc(self,dbfile, sql="select id, doc_txt from doc", ssi=False):  
 		''' spider_docs.sqlit3, 2022.3.11 '''
 		print (f"[indexdoc] started, {dbfile} ", flush=True)
@@ -174,12 +217,35 @@ class util(object):
 					si.update({f"{t.lemma_}:{t.pos_}:{t.tag_}":1}) #book:VERB:VBD
 					si.update({f"{t.lemma_}:LEX:{t.text.lower()}":1}) #book:LEX:booked 
 					if t.pos_ not in ("PROPN","PUNCT"): si.update({f"{t.lemma_}:POS:{t.pos_}":1})
-					si.update({f"{t.dep_}_{t.head.lemma_}_{t.lemma_}:{t.head.lemma_} {t.lemma_}":1})
+					si.update({f"{t.dep_}_{t.head.pos_}_{t.pos_}:{t.head.lemma_} {t.lemma_}":1})
 			except Exception as e:
 				print ("ex:", e, rowid, snt)
 		submit_si(outfile, si)
 		print (f"[si] finished, {dbfile}")
 
+	def clasi(self,dbfile, outfile=None):  #CREATE TABLE clasi ( cp varchar(16) not null, lemma varchar(64) not null,  attr varchar(32) not null,  s varchar(64) not null default '', i int not null default 0, unique key uk(cp,lemma,attr,s), index attrs(cp,attr,s)) engine=myisam;
+		''' clec.spacybs -> clec.clasi, 2022.5.7 '''
+		si = Counter()
+		for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
+			try:
+				doc = spacy.frombs(bs)
+				for t in doc:
+					si.update({f"{t.lemma_}\tLEMMA\t{t.lemma_}":1}) 
+					si.update({f"{t.lemma_}\tLEX\t{t.text.lower()}":1}) 
+					si.update({f"{t.lemma_}\t{t.pos_}\t{t.tag_}":1}) #book  VERB  VBD
+					if t.pos_ not in ("PROPN","PUNCT"): si.update({f"{t.lemma_}\tPOS\t{t.pos_}":1})
+					si.update({f"{t.head.lemma_}\t{t.dep_}_{t.head.pos_}_{t.pos_}\t{t.lemma_}":1})
+			except Exception as e:
+				print ("ex:", e, rowid, snt)
+		name = dbfile.split('.')[0]
+		with open(outfile if outfile else f"{name}.clasi", 'w') as fw: 
+			for s,i in si.items():
+				try:
+					fw.write(f"{name}\t{s}\t{i}\n")
+				except Exception as e:
+					pass
+		print (f"[clasi] finished, {dbfile}")
+
 	def train(self, sntfile, dbfile=None): 
 		''' train clec.snt => clec.spacybs, 2021.8.1 '''
 		if not dbfile : dbfile = sntfile.split(".")[0].lower() + ".spacybs"
@@ -517,5 +583,40 @@ ubuntu@es-corpusly-com-105-249:~/pypi/en$ python spacybs.py load_docjson biz.jso
 started: biz.json biz.doc-spacybs
 finished: biz.json biz.doc-spacybs 	 | using: 951.5030801296234
 
+cikuu@101.35.196.171|kp>select * from clec;  # lemma, attr, name, cnt
++----------------+-------+------------+-----+
+| type           | lem   | attr       | cnt |
++----------------+-------+------------+-----+
+| dobj_VERB_NOUN | open  | door       |  16 |
+| LEX            | book  | book       | 132 |
+| LEX            | book  | booked     |   3 |
+| LEX            | book  | books      |  32 |
+| NP             | book  | a book     |  16 |
+| POS            | book  | NOUN       | 136 |
+| POS            | book  | VERB       |   6 |
+| POS            | sound | ADJ        |  16 |
+| POS            | sound | VERB       |   6 |
+| vtov           | plan  | plan to go |   6 |
++----------------+-------+------------+-----+
+
+[ {'sid': rowid, 'i':t.i, "head":t.head.i, 'lex':t.text, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gpos":t.head.pos_, "glem":t.head.lemma_} for t in doc]
+
+CREATE TABLE gzjc
+(
+`sid` UInt32,
+`i` UInt16,
+`head` UInt16,
+`lex` varchar(64), 
+`lem` varchar(64), 
+`pos` varchar(16), 
+`tag` varchar(16), 
+`dep` varchar(16), 
+`gpos` varchar(16), 
+`glem` varchar(64)
+)ENGINE = MergeTree
+PRIMARY KEY (sid, i)
+ORDER BY (sid, i);
+
+clickhouse-client --query="INSERT INTO gzjc FORMAT JSONEachRow" < gzjc.JSONEachRow
 
 '''
\ No newline at end of file
