@@ -3,13 +3,13 @@ import json,fire,sys, os, hashlib ,time
 import warnings
 warnings.filterwarnings("ignore")
 
-import en  
-from en import terms,verbnet
-from en.dims import docs_to_dims
-attach = lambda doc: ( terms.attach(doc), verbnet.attach(doc), doc.user_data )[-1]  # return ssv, defaultdict(dict)
-
 def index_doc(did, doc):  
 	''' arr: additional attr, such as filename , '''
+	import en  
+	from en import terms,verbnet
+	from en.dims import docs_to_dims
+	attach = lambda doc: ( terms.attach(doc), verbnet.attach(doc), doc.user_data )[-1]  # return ssv, defaultdict(dict)
+
 	arr  = {} #{"did": did}
 	snts = [snt.text for snt in doc.sents]
 	docs = [snt.as_doc() for snt in doc.sents] #spacy.getdoc(snt)
@@ -166,7 +166,8 @@ class ES(object):
 	def hello(self): print (self.es)
 
 	def load(self, infile, idxname, batch=100000): 
-		''' load id-source-file into index, 2022.4.1 '''
+		''' python3 -m so load essaydm.json essaydm 
+		load id-source-file into index, 2022.4.2 '''
 		print(">>started: " , infile, idxname, flush=True )
 		actions=[]
 		for line in readline(infile): 
